@@ -301,7 +301,7 @@ var Search = {
   },
 
   query : function(query) {
-    var stopwords = ["they","such","no","by","into","but","a","then","be","there","or","is","and","at","as","was","not","are","in","their","on","if","will","of","to","it","near","with","this","that","for","the","these"];
+    var stopwords = ["such","of","is","but","on","or","in","there","if","for","not","are","this","will","was","then","near","a","and","that","into","the","be","these","no","by","it","as","at","they","with","to","their"];
 
     // Stem the searchterms and add them to the correct list
     var stemmer = new Stemmer();
